pub struct FunctionTrie { /* private fields */ }Expand description
High-performance prefix trie for function lookup
Implementations
Sourceimpl FunctionTrie
impl FunctionTrie
Sourcepub fn get_prefix(&self, text: &str) -> Option<(String, Arc<Function>)>
pub fn get_prefix(&self, text: &str) -> Option<(String, Arc<Function>)>
Get the longest registered function name that is a prefix of text,
matching strictly from the start of text.
For example, if $ping is registered:
get_prefix("$pingmsoko")→ Some((“$ping”, …))get_prefix("$pingsmmonwind")→ Some((“$ping”, …))get_prefix("$send")→ None (no registered prefix)
The search always starts at position 0 of text; it will never match
a function name found only in the middle of the string.
Sourcepub fn get_completions(&self, prefix: &str) -> Vec<Arc<Function>>
pub fn get_completions(&self, prefix: &str) -> Vec<Arc<Function>>
Get all functions with a given prefix
Sourcepub fn all_functions(&self) -> Vec<Arc<Function>>
pub fn all_functions(&self) -> Vec<Arc<Function>>
Get all functions in the trie