High-performance AST parser for ForgeScript with optional validation
This module provides a fast, single-pass parser that builds a proper Abstract Syntax Tree with extensive optimizations for speed and memory efficiency, plus optional validation.
Structs
- Argument
- Modifiers
- Parse
Error - Parser
- Span
- Validation
Config - Configuration for parser validation
Enums
Functions
- is_
escaped - Determines if a character at a given byte index is escaped by backslashes. This checks for an odd number of preceding backslashes.
- parse
- Parse ForgeScript source code into an AST (no validation)
- parse_
with_ errors - Parse with error handling