pub enum AstNode {
Program {
body: Vec<AstNode>,
span: Span,
},
Text {
content: String,
span: Span,
},
FunctionCall {
name: String,
name_span: Span,
modifier_span: Option<Span>,
args_span: Option<Span>,
args: Option<Vec<Argument>>,
modifiers: Modifiers,
full_span: Span,
span: Span,
},
JavaScript {
code: String,
span: Span,
},
Escaped {
content: String,
span: Span,
},
}Variants
Program
Text
FunctionCall
Fields

name_span: SpanSpan of the function name identifier including any modifier characters (excludes $).

modifier_span: Option<Span>Span of the modifier characters between $ and the name (e.g. !#@[2]).
None when no modifiers are present.

args_span: Option<Span>Span of the argument list including the surrounding [ and ].
None when the function was called without brackets.
JavaScript
Escaped
Implementations