is_escaped

Function is_escaped 

pub fn is_escaped(code: &str, byte_idx: usize) -> bool
Determines if a character at a given byte index is escaped by backslashes. This checks for an odd number of preceding backslashes.