AstNode

Enum AstNode 

pub enum AstNode {
    Program {
        body: Vec<AstNode>,
        span: Span,
    },
    Text {
        content: String,
        span: Span,
    },
    FunctionCall {
        name: String,
        name_span: Span,
        modifier_span: Option<Span>,
        args_span: Option<Span>,
        args: Option<Vec<Argument>>,
        modifiers: Modifiers,
        full_span: Span,
        span: Span,
    },
    JavaScript {
        code: String,
        span: Span,
    },
    Escaped {
        content: String,
        span: Span,
    },
}

Variants



Program

Fields

body: Vec<AstNode>
span: Span


Text

Fields

content: String
span: Span


FunctionCall

Fields

name: String
name_span: Span

Span of the function name identifier including any modifier characters (excludes $).

modifier_span: Option<Span>

Span of the modifier characters between $ and the name (e.g. !#@[2]). None when no modifiers are present.

args_span: Option<Span>

Span of the argument list including the surrounding [ and ]. None when the function was called without brackets.

modifiers: Modifiers
full_span: Span

Full span from the start of modifiers to the closing ] (or end of name when no args). This is the function call without the leading $.

span: Span

Full span from $ to the closing ] (or end of name when no args).



JavaScript

Fields

code: String
span: Span


Escaped

Fields

content: String
span: Span

Implementations

Source

impl AstNode

pub fn span(&self) -> Span

pub fn offset_spans(&mut self, offset: usize)